@@ -89,7 +89,7 @@ parse_primersearch <- function(file_path) {
                    "\tAmplimer length: ([0-9]+) bp", sep = '\n')
   primer_data <- stringr::str_match_all(primer_chunks, pattern)
   primer_data <- as.data.frame(cbind(rep(names(primer_chunks), vapply(primer_data, nrow, numeric(1))),
-                                     do.call(rbind, primer_data)[, -1]), stringsAsFactors = FALSE)
+                                     do.call(rbind, primer_data)[, -1, drop = FALSE]), stringsAsFactors = FALSE)
   # Reformat amplicon data
   colnames(primer_data) <- c("pair_name", "amplimer", "input", "name", "f_primer", "f_start",
                              "f_mismatch",  "r_primer", "r_start", "r_mismatch")
@@ -105,7 +105,7 @@ parse_primersearch <- function(file_path) {
 #' 
 #' A pair of primers are aligned against a set of sequences.
 #' The location of the best hits, quality of match, and predicted amplicons are returned.
-#' Requires the EMBOSS tool kit (\url{http://emboss.sourceforge.net/}) to be installed.
+#' Requires the EMBOSS tool kit (\url{https://emboss.sourceforge.net/}) to be installed.
 #' 
 #' It can be confusing how the primer sequence relates to the binding sites on a
 #' reference database sequence. A simplified diagram can help. For example, if
@@ -347,7 +347,7 @@ primersearch_raw <- function(input = NULL, file = NULL, forward, reverse, mismat
 #' \code{\link{taxmap}} object with two tables is returned: a table with
 #' information for each predicted amplicon, quality of match, and predicted
 #' amplicons, and a table with per-taxon amplification statistics. Requires the
-#' EMBOSS tool kit (\url{http://emboss.sourceforge.net/}) to be installed.
+#' EMBOSS tool kit (\url{https://emboss.sourceforge.net/}) to be installed.
 #' 
 #' It can be confusing how the primer sequence relates to the binding sites on a
 #' reference database sequence. A simplified diagram can help. For example, if
